@@ -8,6 +8,7 @@ from typing import Generator, Optional, Dict, Any, Sequence, Union
 from pathlib import Path
 import numpy as np
 from functools import cmp_to_key
+import string
 
 
 class FileTree:
@@ -239,7 +240,7 @@ class FileTree:
                 Defaults to top-level directory of the main tree. 
                 Can be set to None for an independent tree.
         """
-        if isinstance(precursor, str):
+        if isinstance(precursor, str) or precursor is None:
             precursor = [precursor]
         for name in precursor:
             if name is None:
@@ -272,6 +273,15 @@ class FileTree:
 
             for key, template in assigned.items():
                 if key == '' and name is None:
+                    if parent is None:
+                        for letter in string.ascii_letters:
+                            label = f"tree_top_{letter}"
+                            if (
+                                label not in sub_tree_fill.template_keys() and
+                                label not in self.template_keys()
+                            ):
+                                self._add_actual_template(template, label)
+                                break
                     continue
                 self._add_actual_template(template, add_string + key)
 
@@ -426,9 +436,12 @@ class FileTree:
             return xarray.merge([self.get_mult_glob(k) for k in key], join='outer', fill_value=None if self.return_path else "")
 
 
-    def fill(self, ) -> "FileTree":
+    def fill(self, keep_optionals=True) -> "FileTree":
         """Fills in singular placeholder values.
 
+        Args:
+            keep_optionals: if True keep optional parameters that have not been set
+
         Returns:
             FileTree: new tree with singular placeholder values filled into the templates and removed from the placeholder dict
         """
@@ -443,7 +456,7 @@ class FileTree:
                     new_parent = new_templates[get_keys[old_template.parent]]
                 else:
                     continue
-                new_templates[key] = Template(new_parent, str(Template(None, old_template.unique_part).format_single(self.placeholders, check=False)))
+                new_templates[key] = Template(new_parent, str(Template(None, old_template.unique_part).format_single(self.placeholders, check=False, keep_optionals=True)))
                 del to_assign[key]
         _, mult_placeholders = self.placeholders.split()
         return FileTree(new_templates, mult_placeholders)
