@@ -372,7 +372,7 @@ class Template:
         """
         return self._parts.ordered_placeholders(valid)
 
-    def format_single(self, placeholders: Placeholders, check=True) -> str:
+    def format_single(self, placeholders: Placeholders, check=True, keep_optionals=False) -> str:
         """Formats the template with the placeholders filled in
 
         Only placeholders with a single value are considered.
@@ -380,6 +380,7 @@ class Template:
         Args:
             placeholders (Placeholders): values to fill into the placeholder
             check (bool): skip check for missing placeholders if set to True
+            keep_optionals: if True keep optional parameters that have not been set (will cause the check to fail)
 
         Raises:
             KeyError: if any placeholder is missing
@@ -388,7 +389,9 @@ class Template:
             str: filled in template
         """
         single_placeholders, _ = placeholders.split()
-        template = self._parts.fill_single_placeholders(single_placeholders).remove_optionals()
+        template = self._parts.fill_single_placeholders(single_placeholders)
+        if not keep_optionals:
+            template = template.remove_optionals()
         if check:
             unfilled = template.required_placeholders()
             if len(unfilled) > 0:
